@@ -1,14 +1,18 @@
 package JSON::Parse;
 require Exporter;
 @ISA = qw(Exporter);
-@EXPORT_OK = qw/parse_json json_to_perl valid_json json_file_to_perl/;
+@EXPORT_OK = qw/parse_json
+		json_to_perl
+		valid_json
+		validate_json
+		json_file_to_perl/;
 %EXPORT_TAGS = (
     all => \@EXPORT_OK,
 );
 use warnings;
 use strict;
 use Carp;
-our $VERSION = '0.24';
+our $VERSION = '0.25';
 require XSLoader;
 XSLoader::load (__PACKAGE__, $VERSION);
 
@@ -25,12 +29,15 @@ sub valid_json
 {
     my ($json) = @_;
     if (! $json) {
-	return undef;
+	return 0;
     }
     eval {
-	parse_json (@_);
+	validate_json (@_);
     };
-    return ! $@;
+    if ($@) {
+	return 0;
+    }
+    return 1;
 }
 
 sub json_file_to_perl
